==> prestashop_1.4.9.0.zip: prestashop/modules/avalaratax/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{avalaratax}prestashop>avalaratax_fea2a64a31f1513f4b2565ebfaff597b'] = 'Avalara – AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_ffea2d321be109fc7243cfeb515fe257'] = 'Nur für USA (Wählen Sie Ihr Bundesstaat)';
$_MODULE['<{avalaratax}prestashop>avalaratax_63406c9482c644975f227cc93788e8fb'] = 'Wählen Sie Ihr Land';
$_MODULE['<{avalaratax}prestashop>avalaratax_343618e9fcce53224cc7a47c2145c5e5'] = 'Welche Änderungen führt das Modul in meinem Shop durch?';
$_MODULE['<{avalaratax}prestashop>avalaratax_254f642527b45bc260048e30704edb39'] = 'Konfiguration';
$_MODULE['<{avalaratax}prestashop>avalaratax_6910f753ce21ab6b256a2440296185df'] = 'AvaTax Credentials';
$_MODULE['<{avalaratax}prestashop>avalaratax_2fcecaf04456ae2ceac826fd0ccaaf1c'] = 'Kontonummer';
$_MODULE['<{avalaratax}prestashop>avalaratax_e6b391a8d2c4d45902a23a8b6585703d'] = 'URL';
$_MODULE['<{avalaratax}prestashop>avalaratax_9daf1fb753b42c3cdc8f1d01669cd6d8'] = 'Einstellungen speichern';
$_MODULE['<{avalaratax}prestashop>avalaratax_79ddd6cfbf01f63986f7b114ecc2ca95'] = 'Klicken Sie hier für einen Verbindungstest';
$_MODULE['<{avalaratax}prestashop>avalaratax_dae8ace18bdcbcc6ae5aece263e14fe8'] = 'Optionen';
$_MODULE['<{avalaratax}prestashop>avalaratax_783e8e29e6a8c3e22baa58a19420eb4f'] = 'Sekunden';
$_MODULE['<{avalaratax}prestashop>avalaratax_640fd0cc0ffa0316ae087652871f4486'] = 'Minuten';
$_MODULE['<{avalaratax}prestashop>avalaratax_004bf6c9a40003140292e97330236c53'] = 'Aktion';
$_MODULE['<{avalaratax}prestashop>avalaratax_4bb3e6ea4b1aa93c3429e410129b4be4'] = 'Bestellstatus in Ihrem Shop';
$_MODULE['<{avalaratax}prestashop>avalaratax_add3df7ab84caab59b62f89fdd35ac1f'] = 'Adresse Zeile 1:';
$_MODULE['<{avalaratax}prestashop>avalaratax_6a7b0d5f2f1354e398923d81b0e4d6ab'] = 'Adresse Zeile 2:';
$_MODULE['<{avalaratax}prestashop>avalaratax_57d056ed0984166336b7879c2af3657f'] = 'Stadt';
$_MODULE['<{avalaratax}prestashop>avalaratax_46a2a41cc6e552044816a2d04634545d'] = 'Staat';
$_MODULE['<{avalaratax}prestashop>avalaratax_5e178542b85fb18ca3c459e9a95f4f2e'] = 'Postleitzahl';
$_MODULE['<{avalaratax}prestashop>avalaratax_59716c97497eb9694541f7c3d37b1a4d'] = 'Land';
$_MODULE['<{avalaratax}prestashop>avalaratax_c888438d14855d7d96a2724ee9c306bd'] = 'Einstellungen aktualisiert';
$_MODULE['<{avalaratax}prestashop>avalaratax_63a77eaf9f310dc5def6709c2887dcc4'] = 'Verbindungstest fehlgeschlagen.';
$_MODULE['<{avalaratax}prestashop>avalaratax_3b4f001aa4a4715a2449b8affb2eb3f5'] = 'Fehler aufgetreten';

==> prestashop_1.4.11.1.zip: prestashop/modules/avalaratax/de.php <==
<?php

global $_MODULE;
$_MODULE = array();

$_MODULE['<{avalaratax}prestashop>avalaratax_fea2a64a31f1513f4b2565ebfaff597b'] = 'Avalara – AvaTax';
$_MODULE['<{avalaratax}prestashop>avalaratax_ffea2d321be109fc7243cfeb515fe257'] = 'Nur für USA (Wählen Sie Ihr Bundesstaat)';
$_MODULE['<{avalaratax}prestashop>avalaratax_63406c9482c644975f227cc93788e8fb'] = 'Wählen Sie Ihr Land';
$_MODULE['<{avalaratax}prestashop>avalaratax_2fdfd506efea08144c0794c32ca8250a'] = 'Erstellen Sie ein Konto';
$_MODULE['<{avalaratax}prestashop>avalaratax_254f642527b45bc260048e30704edb39'] = 'Konfiguration';
$_MODULE['<{avalaratax}prestashop>avalaratax_6910f753ce21ab6b256a2440296185df'] = 'AvaTax Credentials';
$_MODULE['<{avalaratax}prestashop>avalaratax_2fcecaf04456ae2ceac826fd0ccaaf1c'] = 'Kontonummer';
$_MODULE['<{avalaratax}prestashop>avalaratax_e6b391a8d2c4d45902a23a8b6585703d'] = 'URL';
$_MODULE['<{avalaratax}prestashop>avalaratax_9daf1fb753b42c3cdc8f1d01669cd6d8'] = 'Einstellungen speichern';
$_MODULE['<{avalaratax}prestashop>avalaratax_79ddd6cfbf01f63986f7b114ecc2ca95'] = 'Klicken Sie hier für einen Verbindungstest';
$_MODULE['<{avalaratax}prestashop>avalaratax_dae8ace18bdcbcc6ae5aece263e14fe8'] = 'Optionen';
$_MODULE['<{avalaratax}prestashop>avalaratax_783e8e29e6a8c3e22baa58a19420eb4f'] = 'Sekunden';
$_MODULE['<{avalaratax}prestashop>avalaratax_640fd0cc0ffa0316ae087652871f4486'] = 'Minuten';
$_MODULE['<{avalaratax}prestashop>avalaratax_004bf6c9a40003140292e97330236c53'] = 'Aktion';
$_MODULE['<{avalaratax}prestashop>avalaratax_4bb3e6ea4b1aa93c3429e410129b4be4'] = 'Bestellstatus in Ihrem Shop';
$_MODULE['<{avalaratax}prestashop>avalaratax_add3df7ab84caab59b62f89fdd35ac1f'] = 'Adresse Zeile 1:';
$_MODULE['<{avalaratax}prestashop>avalaratax_6a7b0d5f2f1354e398923d81b0e4d6ab'] = 'Adresse Zeile 2:';
$_MODULE['<{avalaratax}prestashop>avalaratax_57d056ed0984166336b7879c2af3657f'] = 'Stadt';
$_MODULE['<{avalaratax}prestashop>avalaratax_5e178542b85fb18ca3c459e9a95f4f2e'] = 'Postleitzahl';
$_MODULE['<{avalaratax}prestashop>avalaratax_59716c97497eb9694541f7c3d37b1a4d'] = 'Land';
$_MODULE['<{avalaratax}prestashop>avalaratax_46a2a41cc6e552044816a2d04634545d'] = 'Staat';
$_MODULE['<{avalaratax}prestashop>avalaratax_c888438d14855d7d96a2724ee9c306bd'] = 'Einstellungen aktualisiert';
$_MODULE['<{avalaratax}prestashop>avalaratax_63a77eaf9f310dc5def6709c2887dcc4'] = 'Verbindungstest fehlgeschlagen.';
$_MODULE['<{avalaratax}prestashop>avalaratax_3b4f001aa4a4715a2449b8affb2eb3f5'] = 'Fehler aufgetreten';
